/****************************************************************************
    Qt-BSch3V schematic capture
    Copyright (C) 2002-2005 H.Okada

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*****************************************************************************/

#include <qlineedit.h>
#include <qfont.h>
#include <qfontdialog.h>

#include "editcommentimpl.h"

/* 
 *  Constructs a editcomment which is a child of 'parent', with the 
 *  name 'name' and widget flags set to 'f' 
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
editcomment::editcomment( QWidget* parent,  const char* name, bool modal, Qt::WFlags fl )
    : editcommentBase( parent, name, modal, fl )
{
}

/*  
 *  Destroys the object and frees any allocated resources
 */
editcomment::~editcomment()
{
    // no need to delete child widgets, Qt does it all for us
}

int editcomment::exec()
{
	LineEdit->setText(m_text);
	LineEdit->setFocus();
	return editcommentBase::exec();
}

void editcomment::fontbuttonClicked()
{
	//qDebug("editcomment::fontbuttonClicked()");
	bool ok;
	QFont font=QFontDialog::getFont(&ok,m_font,this);
	if(ok){m_font=font;}
}


void editcomment::accept()
{
	m_text = LineEdit->text();
	editcommentBase::accept();
}


void editcomment::setText(const QString& text)
{
	m_text = text;
}

QString editcomment::text()
{
	return m_text;
}

